default_app_config = 'countryware.apps.CountrywareConfig'

__author__ = 'Val Neekman @ Neekware Inc. [@vneekman]'
__description__ = "A Django application to translate country names"
__version__ = '0.0.4'
